pub struct MathMultiScript { /* private fields */ }Expand description
The <mmultiscripts> element is used to attach an arbitrary number of subscripts and superscripts to an expression at once
Implementations
Sourceimpl MathMultiScript
impl MathMultiScript
Sourcepub fn new(
base: MathML,
lu: Vec<MathML>,
ld: Vec<MathML>,
ru: Vec<MathML>,
rd: Vec<MathML>,
) -> Self
pub fn new( base: MathML, lu: Vec<MathML>, ld: Vec<MathML>, ru: Vec<MathML>, rd: Vec<MathML>, ) -> Self
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn sub_script(base: MathML, sub: MathML) -> Self
pub fn sub_script(base: MathML, sub: MathML) -> Self
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn is_sub_script(&self) -> bool
pub fn is_sub_script(&self) -> bool
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn super_script(base: MathML, sup: MathML) -> Self
pub fn super_script(base: MathML, sup: MathML) -> Self
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn is_super_script(&self) -> bool
pub fn is_super_script(&self) -> bool
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn sub_super_script(base: MathML, sub: MathML, sup: MathML) -> Self
pub fn sub_super_script(base: MathML, sub: MathML, sup: MathML) -> Self
Create a new multi script element with the given base and the given left and right fence characters.
Sourcepub fn is_sub_super_script(&self) -> bool
pub fn is_sub_super_script(&self) -> bool
Create a new multi script element with the given base and the given left and right fence characters.